@@ -458,3 +458,17 @@ class BacklogClient(Client):
         result = self.sf_session.query(soql)
         return [x['Theme__c'] for x in result['records']]
     
+    def get_epics_for_work(self, work):
+        soql = "Select distinct Epic__c from ADM_Work__c where Work__c in ('{}')".format("','".join(work))
+        result = self.sf_session.query(soql)
+        return [x['Epic__c'] for x in result['records']]
+    
+    def get_work_in_epic(self, epicid):
+        soql = "Select Id from ADM_Work__c where Epic__c = '{}'".format(epicid)
+        result = self.sf_session.query(soql)
+        return [x['Id'] for x in result['records']]
+    
+    def filter_work_for_epic(self, work, epicid):
+        soql = "Select Id from ADM_Work__c where Epic__c = '{epic}' and Id in ('{work}')".format(epic=epicid, work="','".join(work))
+        result = self.sf_session.query(soql)
+        return [x['Id'] for x in result['records']]
